CA10_Cl02.html
open | /cms/logout |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Users |
clickAndWait | link=Añadir usuario |
type | id_username | Prueba2
type | id_password1 | prueba
type | id_password2 | prueb
clickAndWait | _save |
verifyTextPresent | Las dos contraseñas no coinciden. |
type | id_password2 | prueba
clickAndWait | _save |
verifyTextPresent | Se añadió con éxito el user "Prueba2". Puede editarlo de nuevo abajo. |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |